/*
 * <one line to give the library's name and an idea of what it does.>
 * Copyright 2013  Luca Beltrame <lbeltrame@kde.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License or (at your option) version 3 or any later version
 * accepted by the membership of KDE e.V. (or its successor approved
 * by the membership of KDE e.V.), which shall act as a proxy
 * defined in Section 14 of version 3 of the license.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

// Own

#include "danboorutablemodel.h"
#include "libdanbooru/danboorupost.h"

// Qt

#include <QDebug>
#include <QPixmap>

namespace Danbooru {

    DanbooruTableModel::DanbooruTableModel(QObject* parent): QAbstractListModel(parent)
    {

    }

    DanbooruTableModel::~DanbooruTableModel()
    {
        qDeleteAll(m_posts);
        m_posts.clear();
    }

    int DanbooruTableModel::rowCount(const QModelIndex& parent) const
    {
        Q_UNUSED(parent)
        return m_posts.size();
    }

    void DanbooruTableModel::addPost(Danbooru::DanbooruPost* post)
    {

        beginInsertRows(QModelIndex(), m_posts.size(), m_posts.size() + 1);
        m_posts.append(post);
        endInsertRows();
    }

    QVariant DanbooruTableModel::data(const QModelIndex& index, int role) const
    {

        if (!index.isValid()) {
            return QVariant();
        }

        if (index.row() >= m_posts.size() || index.row() < 0) {
            return QVariant();
        }

        if (m_posts.isEmpty()) {
            return QVariant();
        }

        if (role == Qt::DisplayRole) {

            Danbooru::DanbooruPost* post = m_posts.at(index.row());

            QVariant variant;
            variant.setValue(post);

            return variant;
        }

        if (role == Qt::DecorationRole) {
            DanbooruPost* post = m_posts.at(index.row());
            const QPixmap* pixmap = post->pixmap();
            return *pixmap;
        }

        return QVariant();
    }

};
